data

package
v0.0.20 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 22, 2025 License: MIT Imports: 14 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddVolume added in v0.0.20

func AddVolume(c context.Context, volume *vo.VolumeVO) (*vo.VolumeVO, error)

func DeleteVolume added in v0.0.20

func DeleteVolume(c context.Context, id string) error

func GetContribution

func GetContribution(c context.Context, id string) (*vo.ContributionVO, error)

Get a single contribution.

  @Summary Get a contribution
	 @Description Retrieve a contribution from the data store.
	 @Param c
	 @Param id

func GetLicense

func GetLicense(c context.Context, id string) (*vo.LicenseVO, error)

func GetPerson

func GetPerson(c context.Context, id string) (*vo.PersonVO, error)

func GetPublisher

func GetPublisher(c context.Context, id string) (*vo.PublisherVO, error)

func GetReview

func GetReview(c context.Context, id string) (*vo.ReviewVO, error)

func GetStudio

func GetStudio(c context.Context, id string) (*vo.StudioVO, error)

func GetSystem

func GetSystem(c context.Context, id string) (*vo.SystemVO, error)

func GetVolume

func GetVolume(c context.Context, id string) (*vo.VolumeVO, error)

func QueryContributions added in v0.0.19

func QueryContributions(c context.Context, params apiutil.QueryParams) ([]*vo.ContributionVO, error)

Get many contributions.

@Summary Query the datastore for contributions.
@Description Given a set of parameters, query the datastore for contributions that match.
@Param c A Context object
@Param params A QueryParams object that contains the parameters for the query

func QueryLicenses added in v0.0.19

func QueryLicenses(c context.Context, params apiutil.QueryParams) ([]*vo.LicenseVO, error)

func QueryPersons added in v0.0.19

func QueryPersons(c context.Context, params apiutil.QueryParams) ([]*vo.PersonVO, error)

func QueryPublishers added in v0.0.19

func QueryPublishers(c context.Context, params apiutil.QueryParams) ([]*vo.PublisherVO, error)

func QueryReviews added in v0.0.19

func QueryReviews(c context.Context, params apiutil.QueryParams) ([]*vo.ReviewVO, error)

func QueryStudios added in v0.0.19

func QueryStudios(c context.Context, params apiutil.QueryParams) ([]*vo.StudioVO, error)

func QuerySystems added in v0.0.19

func QuerySystems(c context.Context, params apiutil.QueryParams) ([]*vo.SystemVO, error)

func QueryVolumes added in v0.0.18

func QueryVolumes(c context.Context, params apiutil.QueryParams) ([]*vo.VolumeVO, error)

func UpdatedAtVolume added in v0.0.20

func UpdatedAtVolume(c context.Context, id string, volume *vo.VolumeVO) (*vo.VolumeVO, error)

Types

This section is empty.

Jump to