Documentation
¶
Index ¶
- func AddVolume(c context.Context, volume *vo.VolumeVO) (*vo.VolumeVO, error)
- func DeleteVolume(c context.Context, id string) error
- func GetContribution(c context.Context, id string) (*vo.ContributionVO, error)
- func GetLicense(c context.Context, id string) (*vo.LicenseVO, error)
- func GetPerson(c context.Context, id string) (*vo.PersonVO, error)
- func GetPublisher(c context.Context, id string) (*vo.PublisherVO, error)
- func GetReview(c context.Context, id string) (*vo.ReviewVO, error)
- func GetStudio(c context.Context, id string) (*vo.StudioVO, error)
- func GetSystem(c context.Context, id string) (*vo.SystemVO, error)
- func GetVolume(c context.Context, id string) (*vo.VolumeVO, error)
- func QueryContributions(c context.Context, params apiutil.QueryParams) ([]*vo.ContributionVO, error)
- func QueryLicenses(c context.Context, params apiutil.QueryParams) ([]*vo.LicenseVO, error)
- func QueryPersons(c context.Context, params apiutil.QueryParams) ([]*vo.PersonVO, error)
- func QueryPublishers(c context.Context, params apiutil.QueryParams) ([]*vo.PublisherVO, error)
- func QueryReviews(c context.Context, params apiutil.QueryParams) ([]*vo.ReviewVO, error)
- func QueryStudios(c context.Context, params apiutil.QueryParams) ([]*vo.StudioVO, error)
- func QuerySystems(c context.Context, params apiutil.QueryParams) ([]*vo.SystemVO, error)
- func QueryVolumes(c context.Context, params apiutil.QueryParams) ([]*vo.VolumeVO, error)
- func UpdatedAtVolume(c context.Context, id string, volume *vo.VolumeVO) (*vo.VolumeVO, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetContribution ¶
Get a single contribution.
@Summary Get a contribution @Description Retrieve a contribution from the data store. @Param c @Param id
func GetPublisher ¶
func QueryContributions ¶ added in v0.0.19
func QueryContributions(c context.Context, params apiutil.QueryParams) ([]*vo.ContributionVO, error)
Get many contributions.
@Summary Query the datastore for contributions. @Description Given a set of parameters, query the datastore for contributions that match. @Param c A Context object @Param params A QueryParams object that contains the parameters for the query
func QueryLicenses ¶ added in v0.0.19
func QueryPersons ¶ added in v0.0.19
func QueryPublishers ¶ added in v0.0.19
func QueryPublishers(c context.Context, params apiutil.QueryParams) ([]*vo.PublisherVO, error)
func QueryReviews ¶ added in v0.0.19
func QueryStudios ¶ added in v0.0.19
func QuerySystems ¶ added in v0.0.19
func QueryVolumes ¶ added in v0.0.18
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.